@@ -565,7 +565,7 @@ def parse_sketch_line(sketch_line, namespace):
 
         def generic_visit(self, n, vc):
             return "".join(filter(None, vc)) or n.text or ""
-        
+
     tree = parser.parse(sketch_line)
     return SketchParser(tree, namespace=namespace).view_or_var
 
@@ -774,114 +774,141 @@ data_ops = {
 }
 
 builders = {
-    "integ": lambda element, subscript_dict, args: builder.add_stock(
+    "integ": lambda element, subscript_dict, merge_subs, args:
+    builder.add_stock(
         identifier=element["py_name"],
         expression=args[0],
         initial_condition=args[1],
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "delay1": lambda element, subscript_dict, args: builder.add_delay(
+    "delay1": lambda element, subscript_dict, merge_subs, args:
+    builder.add_delay(
         identifier=element["py_name"],
         delay_input=args[0],
         delay_time=args[1],
         initial_value=args[0],
         order="1",
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "delay1i": lambda element, subscript_dict, args: builder.add_delay(
+    "delay1i": lambda element, subscript_dict, merge_subs, args:
+    builder.add_delay(
         identifier=element["py_name"],
         delay_input=args[0],
         delay_time=args[1],
         initial_value=args[2],
         order="1",
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "delay3": lambda element, subscript_dict, args: builder.add_delay(
+    "delay3": lambda element, subscript_dict, merge_subs, args:
+    builder.add_delay(
         identifier=element["py_name"],
         delay_input=args[0],
         delay_time=args[1],
         initial_value=args[0],
         order="3",
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "delay3i": lambda element, subscript_dict, args: builder.add_delay(
+    "delay3i": lambda element, subscript_dict, merge_subs, args:
+    builder.add_delay(
         identifier=element["py_name"],
         delay_input=args[0],
         delay_time=args[1],
         initial_value=args[2],
         order="3",
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "delay fixed": lambda element, subscript_dict, args: builder.add_delay_f(
+    "delay fixed": lambda element, subscript_dict, merge_subs, args:
+    builder.add_delay_f(
         identifier=element["py_name"],
         delay_input=args[0],
         delay_time=args[1],
-        initial_value=args[2],
+        initial_value=args[2]
     ),
-    "delay n": lambda element, subscript_dict, args: builder.add_n_delay(
+    "delay n": lambda element, subscript_dict, merge_subs, args:
+    builder.add_n_delay(
         identifier=element["py_name"],
         delay_input=args[0],
         delay_time=args[1],
         initial_value=args[2],
         order=args[3],
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "sample if true": lambda element, subscript_dict, args:
+    "sample if true": lambda element, subscript_dict, merge_subs, args:
     builder.add_sample_if_true(
         identifier=element["py_name"],
         condition=args[0],
         actual_value=args[1],
         initial_value=args[2],
-        subs=element["subs"]
+        subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "smooth": lambda element, subscript_dict, args: builder.add_n_smooth(
+    "smooth": lambda element, subscript_dict, merge_subs, args:
+    builder.add_n_smooth(
         identifier=element["py_name"],
         smooth_input=args[0],
         smooth_time=args[1],
         initial_value=args[0],
         order="1",
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "smoothi": lambda element, subscript_dict, args: builder.add_n_smooth(
+    "smoothi": lambda element, subscript_dict, merge_subs, args:
+    builder.add_n_smooth(
         identifier=element["py_name"],
         smooth_input=args[0],
         smooth_time=args[1],
         initial_value=args[2],
         order="1",
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "smooth3": lambda element, subscript_dict, args: builder.add_n_smooth(
+    "smooth3": lambda element, subscript_dict, merge_subs, args:
+    builder.add_n_smooth(
         identifier=element["py_name"],
         smooth_input=args[0],
         smooth_time=args[1],
         initial_value=args[0],
         order="3",
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "smooth3i": lambda element, subscript_dict, args: builder.add_n_smooth(
+    "smooth3i": lambda element, subscript_dict, merge_subs, args:
+    builder.add_n_smooth(
         identifier=element["py_name"],
         smooth_input=args[0],
         smooth_time=args[1],
         initial_value=args[2],
         order="3",
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "smooth n": lambda element, subscript_dict, args: builder.add_n_smooth(
+    "smooth n": lambda element, subscript_dict, merge_subs, args:
+    builder.add_n_smooth(
         identifier=element["py_name"],
         smooth_input=args[0],
         smooth_time=args[1],
         initial_value=args[2],
         order=args[3],
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "trend": lambda element, subscript_dict, args: builder.add_n_trend(
+    "trend": lambda element, subscript_dict, merge_subs, args:
+    builder.add_n_trend(
         identifier=element["py_name"],
         trend_input=args[0],
         average_time=args[1],
         initial_trend=args[2],
         subs=element["subs"],
+        merge_subs=merge_subs
     ),
-    "get xls data": lambda element, subscript_dict, args: builder.add_ext_data(
+    "get xls data": lambda element, subscript_dict, merge_subs, args:
+    builder.add_ext_data(
         identifier=element["py_name"],
         file_name=args[0],
         tab=args[1],
@@ -889,9 +916,10 @@ builders = {
         cell=args[3],
         subs=element["subs"],
         subscript_dict=subscript_dict,
+        merge_subs=merge_subs,
         keyword=element["keyword"],
     ),
-    "get xls constants": lambda element, subscript_dict, args:
+    "get xls constants": lambda element, subscript_dict, merge_subs, args:
     builder.add_ext_constant(
         identifier=element["py_name"],
         file_name=args[0],
@@ -899,8 +927,9 @@ builders = {
         cell=args[2],
         subs=element["subs"],
         subscript_dict=subscript_dict,
+        merge_subs=merge_subs,
     ),
-    "get xls lookups": lambda element, subscript_dict, args:
+    "get xls lookups": lambda element, subscript_dict, merge_subs, args:
     builder.add_ext_lookup(
         identifier=element["py_name"],
         file_name=args[0],
@@ -909,12 +938,13 @@ builders = {
         cell=args[3],
         subs=element["subs"],
         subscript_dict=subscript_dict,
+        merge_subs=merge_subs,
     ),
-    "initial": lambda element, subscript_dict, args:
+    "initial": lambda element, subscript_dict, merge_subs, args:
     builder.add_initial(
         identifier=element["py_name"],
         value=args[0]),
-    "a function of": lambda element, subscript_dict, args:
+    "a function of": lambda element, subscript_dict, merge_subs, args:
     builder.add_incomplete(
         element["real_name"], args
     ),
@@ -1269,16 +1299,14 @@ def parse_general_expression(element, namespace={}, subscript_dict={},
                 else:
                     datastr = n.text
 
-                # Create a cleaner dictionary of coords using _subscript_dict
-                # when possible
-                utils.simplify_subscript_input(coords, subscript_dict,
-                                               return_full=True)
-
                 return builder.build_function_call(
                     functions_utils["DataArray"],
                     [datastr,
-                     utils.simplify_subscript_input(coords, subscript_dict),
-                     repr(list(coords))]
+                     utils.simplify_subscript_input(
+                         coords, subscript_dict,
+                         return_full=True,
+                         merge_subs=element["merge_subs"]),
+                     repr(element["merge_subs"])]
                     )
             else:
                 return n.text.replace(" ", "")
@@ -1339,14 +1367,21 @@ def parse_general_expression(element, namespace={}, subscript_dict={},
         def visit_build_call(self, n, vc):
             # use only the dict with the final subscripts
             # needed for the good working of externals
-
-            subs = {
+            subs_dict = {
                 k: subscript_dict[k] for k in
-                elements_subs_dict[element["py_name"]]
+                element["merge_subs"]
             }
+            # add subscript ranges given in expr
+            subs_dict.update({
+                sub: subscript_dict[sub] for sub in element['subs']
+                if sub in subscript_dict
+            })
+
             self.kind = "component"
             builder_name = vc[0].strip().lower()
-            name, structure = builders[builder_name](element, subs, vc[4])
+            name, structure = builders[builder_name](
+                element, subs_dict, element["merge_subs"],
+                vc[4])
 
             self.new_structure += structure
 
@@ -1454,8 +1489,20 @@ def parse_lookup_expression(element, subscript_dict):
         def visit_excelLookup(self, n, vc):
             arglist = vc[3].split(",")
             arglist = [arg.replace("\\ ", "") for arg in arglist]
+            # use only the dict with the final subscripts
+            # needed for the good working of externals
+            subs_dict = {
+                k: subscript_dict[k] for k in
+                element["merge_subs"]
+            }
+            # add subscript ranges given in expr
+            subs_dict.update({
+                sub: subscript_dict[sub] for sub in element['subs']
+                if sub in subscript_dict
+            })
             trans, structure = builders["get xls lookups"](
-                element, subscript_dict, arglist
+                element, subs_dict,
+                element["merge_subs"], arglist
             )
 
             self.translation = trans
@@ -1536,10 +1583,17 @@ def translate_section(section, macro_list, sketch, root_path, subview_sep=""):
                 elements_subs_dict[element["py_name"]] = [element["subs"]]
 
     elements_subs_dict = {
-        el: utils.make_merge_list(elements_subs_dict[el], subscript_dict)
+        el: utils.make_merge_list(elements_subs_dict[el], subscript_dict, el)
         for el in elements_subs_dict
     }
 
+    for element in model_elements:
+        if "py_name" in element and element["py_name"] in elements_subs_dict:
+            element["merge_subs"] =\
+                elements_subs_dict[element["py_name"]]
+        else:
+            element["merge_subs"] = None
+
     # Parse components to python syntax.
     for element in model_elements:
         if (element["kind"] == "component" and "py_expr" not in element) or \
@@ -1551,15 +1605,16 @@ def translate_section(section, macro_list, sketch, root_path, subview_sep=""):
                 namespace=namespace,
                 subscript_dict=subscript_dict,
                 macro_list=macro_list,
-                elements_subs_dict=elements_subs_dict,
                 subs_compatibility=subs_compatibility_dict,
+                elements_subs_dict=elements_subs_dict
             )
             element.update(translation)
             model_elements += new_structure
 
         elif element["kind"] == "lookup":
             translation, new_structure = parse_lookup_expression(
-                element, subscript_dict
+                element,
+                subscript_dict=subscript_dict
             )
             element.update(translation)
             model_elements += new_structure
